clear all
cd "C:\"
set more off
clear
use Dataset_DomesticEffects.dta

keep quarter quarterly year wb_code wntighti wneo wnnkirt whntighti whneo

reshape wide wntighti wneo wnnkirt whntighti whneo, i(quarterly) j(wb_code) string

* Create BRICS capital controls series

local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local myvars{  
egen `k'BRIC = rowtotal(`k'BRA `k'CHN `k'IND `k'RUS `k'ZAF), missing
}

local mycountries ARG BRA CHL CHN COL IDN IND KOR MEX MYS PER PHL RUS THA TUR ZAF
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
gen `j'BRIC`k'=`j'BRIC
}
}

* Create MULTILATERAL capital controls series

* Latin America
local mycountries ARG CHL COL MEX PER
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
gen `j'ML`k'=`j'BRA
}
}

* Europe
local mycountries TUR
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
gen `j'ML`k'=`j'RUS
}
}

* Asia
local mycountries IDN MYS KOR PHL THA 
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
egen `j'ML`k' =  rowtotal(`j'CHN  `j'IND), missing
}
}

* Brazil
local mycountries BRA 
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
egen `j'ML`k' =  rowtotal(`j'CHN `j'IND `j'RUS `j'ZAF), missing
}
}

* China
local mycountries CHN 
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
egen `j'ML`k' = rowtotal(`j'BRA `j'IND `j'RUS `j'ZAF), missing
}
}

* India
local mycountries IND 
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
egen `j'ML`k' = rowtotal(`j'CHN  `j'BRA  `j'RUS  `j'ZAF), missing
}
}

* Russia
local mycountries RUS 
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
egen `j'ML`k' = rowtotal(`j'CHN `j'IND `j'BRA `j'ZAF), missing
}
}

* South Africa
local mycountries ZAF 
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
egen `j'ML`k' = rowtotal(`j'CHN `j'IND  `j'RUS  `j'BRA), missing
}
}

* Create transformed capital controls series for each BRICS country

* Brazil
local mycountries ARG BRA CHL CHN COL IDN IND KOR MEX MYS PER PHL RUS THA TUR ZAF
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
gen `j'BRA`k'=`j'BRA
}
}

* China
local mycountries ARG BRA CHL CHN COL IDN IND KOR MEX MYS PER PHL RUS THA TUR ZAF
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
gen `j'CHN`k'=`j'CHN
}
}

* India
local mycountries ARG BRA CHL CHN COL IDN IND KOR MEX MYS PER PHL RUS THA TUR ZAF
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
gen `j'IND`k'=`j'IND
}
}

* Russia
local mycountries ARG BRA CHL CHN COL IDN IND KOR MEX MYS PER PHL RUS THA TUR ZAF
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
gen `j'RUS`k'=`j'RUS
}
}

* South Africa
local mycountries ARG BRA CHL CHN COL IDN IND KOR MEX MYS PER PHL RUS THA TUR ZAF
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
gen `j'ZAF`k'=`j'ZAF
}
}

* Drop original series

local mycountries ARG BRA CHL CHN COL IDN IND KOR MEX MYS PER PHL RUS THA TUR ZAF
local myvars wntighti wneo wnnkirt whntighti whneo
foreach k of local mycountries{
foreach j of local myvars{
drop `j'`k'
}
}

local myvars wntighti wneo wnnkirt whntighti whneo
foreach j of local myvars{
drop `j'BRIC
}

reshape long wntightiBRIC wneoBRIC wnnkirtBRIC whntightiBRIC whneoBRIC wntightiML wneoML wnnkirtML whntightiML whneoML ///
wntightiBRA wneoBRA wnnkirtBRA whntightiBRA whneoBRA wntightiCHN wneoCHN wnnkirtCHN whntightiCHN whneoCHN wntightiIND wneoIND wnnkirtIND whntightiIND whneoIND ///
wntightiRUS wneoRUS whntightiRUS whneoRUS wnnkirtRUS wntightiZAF wneoZAF wnnkirtZAF whntightiZAF whneoZAF, i(quarterly) j(wb_code) string



// SET PANEL
encode wb_code, gen(ccode)
*encode quarterly, generate(quarterly)
format quarterly %tq

tsset ccode quarterly
set more off

capture drop ccode
encode wb_code, gen(ccode)

tsset ccode quarterly

drop quarter year
gen quarter = quarter(dofq(quarterly))
gen year = year(dofq(quarterly))
gen date = string(year)+"q"+string(quarter)


ren ccode id
tsset id quarterly
keep if quarterly>=q(2001q1) & quarterly<=q(2012q4)
tsfill, full

drop quarter date year
gen quarter = quarter(dofq(quarterly))
gen year = year(dofq(quarterly))
gen date = string(year)+"q"+string(quarter)

foreach x in wb_code {
gsort id -`x'
by id: replace `x'=`x'[_n-1] if _n>1
}

tsset id quarterly


order date wb_code id quarterly
 capture drop g1-g18
 tabulate id, gen(g) // Generate dummy variables for countries
 
 encode date, generate(date1)
drop date
ren date1 date
format date %tq

save MLcapcontrols, replace



clear all
use Dataset_DomesticEffects.dta

// Merge with ML capital controls 
sort wb_code quarterly
*ren quarterly date
merge 1:1 wb_code quarterly using MLcapcontrols
tab wb_code if _merge==1
tab year if _merge~=3
drop _merge
order ifs_code id quarterly wb_code
format date %tq

// Reorder countries to avoid ARG in the first position (required for RATS)
gsort -ifs_code quarterly

keep ifs_code id quarterly wb_code dar_diff1 wneo dgin_saz wntightiML wntighti dgout_saz dxr MP2_dyBCPNFS CrudeOilPrice us_ff_sr USgdp_gr crisis date

save Dataset_MultilateralEffects, replace

*** BRICS
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="BRA" | wb_code=="CHN" | wb_code=="IND"  |wb_code=="RUS" |wb_code=="ZAF"

save Dataset_MultilateralEffects_BRICS, replace

*** Latin America
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="ARG" | wb_code=="PER" | wb_code=="CHL"  |wb_code=="COL" |wb_code=="MEX"

save Dataset_MultilateralEffects_latinamerica, replace

*** Asia
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="THA" | wb_code=="PHL" | wb_code=="IDN"  |wb_code=="MYS" |wb_code=="KOR"

save Dataset_MultilateralEffects_asia, replace

*** Argentina
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="ARG"

save Dataset_MultilateralEffects_argetina, replace

*** Brazil
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="BRA"

save Dataset_MultilateralEffects_brazil, replace

*** Chile
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="CHL"

save Dataset_MultilateralEffects_chile, replace

*** China
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="CHN"

save Dataset_MultilateralEffects_china, replace

*** Colombia
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="COL"

save Dataset_MultilateralEffects_colombia, replace

*** Indonesia
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="IDN"

save Dataset_MultilateralEffects_indonesia, replace

*** India
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="IND"

save Dataset_MultilateralEffects_india, replace

*** South Korea
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="KOR"

save Dataset_MultilateralEffects_korea, replace

*** Mexico
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="MEX"

save Dataset_MultilateralEffects_mexico, replace

*** Malaysia
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="MYS"

save Dataset_MultilateralEffects_malaysia, replace

*** Peru
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="PER"

save Dataset_MultilateralEffects_peru, replace

*** Philippines
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="PHL"

save Dataset_MultilateralEffects_philippines, replace

*** Russia
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="RUS"

save Dataset_MultilateralEffects_russia, replace

*** Thailand
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="THA"

save Dataset_MultilateralEffects_thailand, replace

*** Turkey
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="TUR"

save Dataset_MultilateralEffects_turkey, replace

*** South Africa
clear all
use Dataset_MultilateralEffects, clear

keep if wb_code=="ZAF"

save Dataset_MultilateralEffects_southafrica, replace
